@@ -6,13 +6,14 @@
 
 function main(pass, node)
 {
-//     if (pass.transitType != KPkPass.BoardinPass.Air) { // TODO this needs to be registered in the engine
-//         return null;
-//     }
-
-    var res = node.result[0];
-    res.reservationFor.departureAirport.name = pass.field["origin"].label;
-    res.reservationFor.arrivalAirport.name = pass.field["destination"].label;
+    let res = node.result[0];
+    if (res["@type"] === "FlightReservation") {
+        res.reservationFor.departureAirport.name = pass.field["origin"].label;
+        res.reservationFor.arrivalAirport.name = pass.field["destination"].label;
+    } else {
+        res.reservationFor.departureStation.name = pass.field["origin"].label;
+        res.reservationFor.arrivalStation.name = pass.field["destination"].label;
+    }
 
     const back = pass.backFields;
     const cancelLink = back.find(item => item.key === "cancel");
